#ifndef COREMOIDAPPLET_HEADER
#define COREMOIDAPPLET_HEADER

#include <KIcon>
#include <QVector>

#include <Plasma/Applet>
#include <Plasma/Svg>

#include "cpustat.h"

class QSizeF;
class QTimer;
class Ui_coremoidConfig;
class KDialog;

class CoreMoidApplet : public Plasma::Applet
{
		Q_OBJECT
	public:
		CoreMoidApplet ( QObject *parent, const QVariantList &args );
		~CoreMoidApplet();

		void init();
		void paintInterface ( QPainter *painter,
		                      const QStyleOptionGraphicsItem *option,
		                      const QRect& contentsRect );
		void setContentSize ( const QSizeF& size );
		QSizeF contentSizeHint() const;
		QList<QAction*> contextActions();

		Qt::Orientations expandingDirections() const;
		void constraintsUpdated(Plasma::Constraints constraints);

	private:
		KIcon m_icon;
		QSizeF m_size;
		QTimer *m_timer;
		int m_cpu_count;
		QVector<QRect> m_rects;
		QVector<CpuStat> m_stats, m_stats_new;
		QString m_current_govenor;
		QList<QAction*> m_actions;
		QAction *m_performance, *m_powersave, *m_ondemand, *m_conservative;
		QFont m_font;
		bool m_isHovered;
		QColor m_boxColor;
		QColor m_textColor;
		int m_boxAlpha;
		int m_boxHoverAlpha;
		Ui_coremoidConfig *m_config;
		KDialog *m_dialog;
		int m_orientation;
		bool m_show_governor;

	public slots:
		void doSomething();
		void updateGovenorSelection();
		void setPerformance();
		void setPowersave();
		void setOndemand();
		int getCurrentFreq();
		void setConservative();
		void setGovenor(const QString &name);
		void showConfigurationInterface();
		void configAccepted();

	public Q_SLOTS:
		virtual void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
		virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);

	private:
		void paintText(QPainter *p, const QRect &pos, const QString &text);
		void paintBar ( QPainter *p, const QRect &r, int perc, int orientation = 0 );
		void readCpus(QVector<CpuStat> &stats);
		void readCurrentGovenor();
		void paintLabel(QPainter *p, const QRect &contentsRect, const QString& labelText);
		bool textWillFit(QPainter *p, const QRect &pos, const QString &text);
};

// This is the command that links your applet to the .desktop file
K_EXPORT_PLASMA_APPLET ( coremoid, CoreMoidApplet )
#endif
